@@ -967,7 +967,7 @@ void DrawTime(Window win)
 	int i;
 	int firstDigit = 0;
 	int time_left;
-	if ( state.time_left > 0 )
+	if ( (state.time_left > 0) && (state.system_time) )
 		time_left = state.time_left;
 	else
 		time_left = state.time_estimate;
