@@ -73,6 +73,8 @@ void defaults()
 	state.ac_line_status = AC_UNKNOWN;
 	state.battery_status = BATTERY_UNKNOWN;
 	state.percent = -1;
+	state.system_levels = 1;
+	state.system_time = 1;
 
 	state.color_depth = 0; /* use default */
 
@@ -95,8 +97,9 @@ void usage()
         printf("-standout       standing out rather than being pushed in\n");
 	printf("-dev <device>	use the specified file as APM device\n");
 	printf("-fail 		fail if cannot read the APM device\n");
-        printf("-syslevels      use system - defined levels for battery status\n");
-        printf("-systime        do not calculate battery life time\n\n");
+        printf("-[no]syslevels  [do not] use system - defined levels for battery status\n");
+        printf("-[no]systime    [calculate] or not battery life time instead of\n");
+	printf("                using system values supplied by APM driver\n\n");
         printf("-status <color> to be used as the color for time and percent\n");
         printf("-green <color>  to be used as green for the labels\n");
         printf("-yellow <color> to be used as yellow for the labels\n");
@@ -110,7 +113,7 @@ void usage()
 /* print the version of the tool */
 void version()
 {
-        printf("asapm : Advanced Power Management monitor version 2.11\n");
+        printf("asapm : Advanced Power Management monitor version 2.13\n");
 }               
 
 /*
@@ -172,25 +175,23 @@ void    parsecmdline(int argc, char *argv[])
                                 embossed=0;
                         } else if (!strncmp(argument,"-syslevels",10)) {
                                 state.system_levels=1;
+                        } else if (!strncmp(argument,"-nosyslevels",12)) {
+                                state.system_levels=0;
                         } else if (!strncmp(argument,"-systime",8)) {
                                 state.system_time=1;
+                        } else if (!strncmp(argument,"-nosystime",10)) {
+                                state.system_time=0;
                         } else if (!strncmp(argument,"-dev",4)) {
                                 if (++i >= argc)
                                         usage();
                                 safecopy(apm_device_file, argv[i], 256);
                         } else if (!strncmp(argument,"-fail",5)) {
                                 state.fail=1;
-                        } else if (!strncmp(argument,"-u",2)) {
-                                if (++i >= argc)
-                                        usage();
-                                state.apm_interval = 1000000L * atoi(argv[i]);
-                                if ( state.apm_interval < 1 )  
-                                        state.apm_interval = APM_INTERVAL;
                         } else if (!strncmp(argument,"-position",9)) {
                                 if (++i >= argc)
                                         usage();
                                 safecopy(mainGeometry, argv[i], 50);
-                        } else if (!strncmp(argument,"-status",6)) {
+                        } else if (!strncmp(argument,"-status",7)) {
                                 if (++i >= argc)
                                         usage();
                                 safecopy(statuscolor, argv[i], 50);
@@ -206,7 +207,7 @@ void    parsecmdline(int argc, char *argv[])
                                 if (++i >= argc)
                                         usage();
                                 safecopy(redcolor, argv[i], 50);
-                        } else if (!strncmp(argument,"-lower",5)) {
+                        } else if (!strncmp(argument,"-lower",6)) {
                                 if (++i >= argc)
                                         usage();
                                 safecopy(slidercolor, argv[i], 50);
@@ -225,6 +226,12 @@ void    parsecmdline(int argc, char *argv[])
                                 if ( ( state.color_depth != 8 )  
 				  && ( state.color_depth != 16 ) )
                                         usage();
+                        } else if (!strncmp(argument,"-u",2)) {
+                                if (++i >= argc)
+                                        usage();
+                                state.apm_interval = 1000000L * atoi(argv[i]);
+                                if ( state.apm_interval < 1 )  
+                                        state.apm_interval = APM_INTERVAL;
                         } else if (!strncmp(argument,"-V",2)) { 
                                 version();
                                 exit(0);
