@@ -55,8 +55,8 @@ struct apm_state {
 	int time_estimate;
 
 	/* state variables */
-	int system_levels;
-	int system_time;
+	int system_levels;	/* Use system level for warnings */
+	int system_time;	/* Use system generated time to empty */
 	long int apm_interval; /* interval to check the APM status */
 	long int x11_interval; /* interval to check for X11 events */
 
